/****************************************************************************
 *   PROJECT: Classroom Raytracer
 *   FILE:    main.cpp
 *   CONTENT: Main program
 *
 *   AUTHOR:  Bert Freudenberg (bf)
 *   ADDRESS: University of Magdeburg, Germany
 *   EMAIL:   bert@isg.cs.uni-magdeburg.de
 *   RCSID:   $Id: main.cpp,v 1.3 2001/11/23 17:41:28 bert Exp bert $
 *
 *****************************************************************************/

#include "raytracer.h"
#include "image.h"
#include <fstream>
using namespace std;

int main(int argc, char *argv[])
{
  if (argc < 3) {
    cerr << "Usage: " << argv[0] << " in-file out-file.ppm" << endl;
    return 1;
  }

  ifstream is(argv[1]);
  if (!is) {
    cerr << "File not found: " << argv[1] << endl;
    return 1;
  }

  ofstream os(argv[2]);
  if (!os) {
    cerr << "Cannot write to: " << argv[2] << endl;
    return 1;
  }

  Raytracer raytracer;

  cerr << "Reading from " << argv[1] << endl;
  if (!raytracer.read(is)) {
    cerr << "Error while reading!" << endl;
    return 1;
  }

  Image img(400,400);

  cerr << "Tracing" << endl;
  raytracer.trace(img);

  cerr << "Writing to " << argv[2] << endl;

#ifdef _WIN32
  //os.setmode(filebuf::binary);
#endif

  img.write_ppm(os, false);

  cerr << "Done" << endl;
  return 0;
}


